==============
NFQP3.4 - NetfilterQueue patched for Python3.4
==============

NetfilterQueue provides access to packets matched by an iptables rule in
Linux. Packets so matched can be accepted, dropped, altered, or given a mark.

Libnetfilter_queue (the netfilter library, not this module) is part of the
`Netfilter project <http://netfilter.org/projects/libnetfilter_queue/>`_.

Installation
============

NFQP3.4 is a python3.4 pached NetFilterQueue  module that links against libnetfilter_queue. 


From PyPI
---------

To install from PyPI by pip3::

    pip3 install NFQP3.4



Source
======

https://github.com/kti/python-netfilterqueue

License
=======

Copyright (c) 2011, Kerkhoff Technologies, Inc.

`MIT licensed <https://github.com/kti/python-netfilterqueue/blob/master/LICENSE.txt>`_

